<?php

namespace Drupal\oswald\Entity;

use Drupal\Core\Entity\Annotation\ContentEntityType;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityTypeInterface;

/**
 * Defines the oswald_chatbot entity.
 *
 * @ingroup oswald_chatbot
 *
 * @ContentEntityType(
 *   id = "oswald_chatbot",
 *   label = @Translation("Oswald Chatbot"),
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\oswald\OswaldChatbotListBuilder",
 *     "views_data" = "Drupal\views\EntityViewsData",
 *     "storage_schema" = "Drupal\oswald\OswaldChatbotStorageSchema",
 *     "form" = {
 *       "default" = "Drupal\oswald\Form\OswaldChatbotForm",
 *       "add" = "Drupal\oswald\Form\OswaldChatbotForm",
 *       "edit" = "Drupal\oswald\Form\OswaldChatbotForm",
 *       "delete" = "Drupal\oswald\Form\OswaldChatbotDeleteForm",
 *     },
 *     "access" = "Drupal\oswald\OswaldChatbotAccessControlHandler",
 *   },
 *   base_table = "oswald_chatbot",
 *   admin_permission = "administer oswald configuration",
 *   entity_keys = {
 *     "id" = "id",
 *     "uuid" = "uuid",
 *   },
 *   links = {
 *     "canonical" = "/admin/config/oswald/bots/{oswald_chatbot}",
 *     "edit-form" = "/admin/config/oswald/bots/{oswald_chatbot}/edit",
 *     "test-form" = "/admin/config/oswald/bots/{oswald_chatbot}/test",
 *     "delete-form" = "/admin/config/oswald/bots/{oswald_chatbot}/edit",
 *     "collection" = "/admin/config/oswald/bots"
 *   },
 * )
 */
class OswaldChatbot extends ContentEntityBase {

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['name'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Name'))
      ->setDefaultValue('')
      ->setRequired(TRUE)
      ->setSetting('max_length', 255)
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'string',
        'weight' => 1,
      ])
      ->setDisplayOptions('form', [
        'type' => 'text_textfield',
        'weight' => 1,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['oswald_chatbot_id'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Bot id'))
      ->setDescription(t('The ID of the Oswald chatbot widget.'))
      ->setDefaultValue('')
      ->setRequired(TRUE)
      ->setSetting('max_length', 255)
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'string',
        'weight' => 2,
      ])
      ->setDisplayOptions('form', [
        'type' => 'text_textfield',
        'weight' => 2,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['enabled'] = BaseFieldDefinition::create('boolean')
      ->setLabel(t('Enabled'))
      ->setRequired(FALSE)
      ->setDefaultValue(FALSE)
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'boolean',
        'weight' => 3,
      ])
      ->setDisplayOptions('form', [
        'type' => 'boolean_checkbox',
        'weight' => 3,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['environment'] = BaseFieldDefinition::create('list_string')
      ->setLabel(t('Environment'))
      ->setRequired(TRUE)
      ->setDefaultValue('prod')
      ->setSetting('allowed_values', [
        'acc' => 'Acceptance',
        'prod' => 'Production',

      ])
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'list_default',
        'weight' => 4,
      ])
      ->setDisplayOptions('form', [
        'type' => 'options_select',
        'weight' => 4,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    return $fields;
  }

}
